@@ -4,7 +4,7 @@ measure choice for brevity (although both measure and features are chosen)"""
 from collections import namedtuple
 import json
 from os import makedirs
-from posixpath import dirname
+from os.path import dirname
 
 import numpy as np
 
@@ -13,8 +13,7 @@ from aimsim.exceptions import InvalidConfigurationError
 from aimsim.ops import Descriptor, SimilarityMeasure
 from aimsim.utils.plotting_scripts import plot_multiple_barchart
 from .task import Task
-from .see_property_variation_with_similarity \
-    import SeePropertyVariationWithSimilarity
+from .see_property_variation_with_similarity import SeePropertyVariationWithSimilarity
 
 
 class MeasureSearch(Task):
@@ -33,19 +32,20 @@ class MeasureSearch(Task):
         InvalidConfigurationError: If correlation_type does not match
                                    implemented types.
         """
-        self.plot_settings = {'colors': ['#78DEC7', '#FB7AFC', '#FBC7F7'],
-                              'xticksize': 10,
-                              'yticksize': 20,
-                              'title': "",
-                              'title_fontsize': 24,
-                              'xlabel_fontsize': 20,
-                              'ylabel_fontsize': 20,
-                              }
-        self.plot_settings.update(self.configs.get("plot_settings",
-                                                   {}))
+        self.plot_settings = {
+            "colors": ["#78DEC7", "#FB7AFC", "#FBC7F7"],
+            "xticksize": 10,
+            "yticksize": 20,
+            "title": "",
+            "title_fontsize": 24,
+            "xlabel_fontsize": 20,
+            "ylabel_fontsize": 20,
+        }
+        self.plot_settings.update(self.configs.get("plot_settings", {}))
         try:
             self.prop_var_w_similarity = SeePropertyVariationWithSimilarity(
-                correlation_type=self.configs.get('correlation_type'))
+                correlation_type=self.configs.get("correlation_type")
+            )
         except InvalidConfigurationError as e:
             raise e
         self.log_fpath = self.configs.get("log_file_path", None)
@@ -53,16 +53,17 @@ class MeasureSearch(Task):
             log_dir = dirname(self.log_fpath)
             makedirs(log_dir, exist_ok=True)
 
-    def __call__(self,
-                 molecule_set_configs,
-                 fingerprint_type=None,
-                 fingerprint_params=None,
-                 similarity_measure=None,
-                 subsample_subset_size=0.01,
-                 optim_algo='max_min',
-                 show_top=0,
-                 only_metric=True,
-                 ):
+    def __call__(
+        self,
+        molecule_set_configs,
+        fingerprint_type=None,
+        fingerprint_params=None,
+        similarity_measure=None,
+        subsample_subset_size=0.01,
+        optim_algo="max_min",
+        show_top=0,
+        only_metric=True,
+    ):
         """
         Calculate the correlation in the properties of molecules in set
         and their nearest and furthest neighbors using different
@@ -124,13 +125,17 @@ class MeasureSearch(Task):
                    More is better.
 
         """
-        print(f'Using subsample size {subsample_subset_size} for '
-              f'measure search')
-        trial_ = namedtuple('trial_', ['fingerprint_type',
-                                       'similarity_measure',
-                                       'nearest_neighbor_correlation',
-                                       'furthest_neighbor_correlation',
-                                       'score_'])
+        print(f"Using subsample size {subsample_subset_size} for " f"measure search")
+        trial_ = namedtuple(
+            "trial_",
+            [
+                "fingerprint_type",
+                "similarity_measure",
+                "nearest_neighbor_correlation",
+                "furthest_neighbor_correlation",
+                "score_",
+            ],
+        )
         if fingerprint_type is None:
             all_fingerprint_types = Descriptor.get_supported_fprints()
             fingerprint_params = None
@@ -138,7 +143,7 @@ class MeasureSearch(Task):
             all_fingerprint_types = [fingerprint_type]
         if similarity_measure is None:
             if only_metric:
-                print('Only trying measures with valid distance metrics')
+                print("Only trying measures with valid distance metrics")
             all_similarity_measures = SimilarityMeasure.get_uniq_metrics()
         else:
             all_similarity_measures = [similarity_measure]
@@ -147,57 +152,73 @@ class MeasureSearch(Task):
         if fingerprint_params is None:
             fingerprint_params = {}
         for similarity_measure in all_similarity_measures:
-            if only_metric and not SimilarityMeasure(
-                    metric=similarity_measure).is_distance_metric():
+            if (
+                only_metric
+                and not SimilarityMeasure(
+                    metric=similarity_measure
+                ).is_distance_metric()
+            ):
                 continue
             if is_verbose:
-                print(f'Trying {similarity_measure} similarity')
+                print(f"Trying {similarity_measure} similarity")
             for fingerprint_type in all_fingerprint_types:
                 if is_verbose:
-                    print(f'Trying {fingerprint_type} fingerprint')
+                    print(f"Trying {fingerprint_type} fingerprint")
                 try:
                     molecule_set = MoleculeSet(
                         molecule_database_src=molecule_set_configs[
-                            'molecule_database_src'],
+                            "molecule_database_src"
+                        ],
                         molecule_database_src_type=molecule_set_configs[
-                            'molecule_database_src_type'],
+                            "molecule_database_src_type"
+                        ],
                         similarity_measure=similarity_measure,
                         fingerprint_type=fingerprint_type,
                         fingerprint_params=fingerprint_params,
                         is_verbose=is_verbose,
-                        n_threads=molecule_set_configs.get(
-                            'n_threads', 1),
-                        sampling_ratio=subsample_subset_size)
+                        n_threads=molecule_set_configs.get("n_threads", 1),
+                        sampling_ratio=subsample_subset_size,
+                    )
                 except (InvalidConfigurationError, ValueError, RuntimeError) as e:
                     if is_verbose:
-                        print(f'Could not try {fingerprint_type} with '
-                              f'similarity measure {similarity_measure} due to '
-                              f'{e}')
+                        print(
+                            f"Could not try {fingerprint_type} with "
+                            f"similarity measure {similarity_measure} due to "
+                            f"{e}"
+                        )
                     continue
-                nearest_corr, nearest_p_val = self.prop_var_w_similarity. \
-                    get_property_correlations_in_most_similar(
-                        molecule_set)
-                furthest_corr, furthest_p_val = self.prop_var_w_similarity. \
-                    get_property_correlations_in_most_dissimilar(
-                        molecule_set)
-                if optim_algo == 'max_min':
+                (
+                    nearest_corr,
+                    nearest_p_val,
+                ) = self.prop_var_w_similarity.get_property_correlations_in_most_similar(
+                    molecule_set
+                )
+                (
+                    furthest_corr,
+                    furthest_p_val,
+                ) = self.prop_var_w_similarity.get_property_correlations_in_most_dissimilar(
+                    molecule_set
+                )
+                if optim_algo == "max_min":
                     score_ = nearest_corr - abs(furthest_corr)
-                elif optim_algo == 'max':
+                elif optim_algo == "max":
                     score_ = nearest_corr
-                elif optim_algo == 'min':
+                elif optim_algo == "min":
                     score_ = -abs(furthest_corr)
                 else:
-                    raise InvalidConfigurationError(f'{optim_algo} '
-                                                    f'not implemented')
-                all_scores.append(trial_(
-                    fingerprint_type=fingerprint_type,
-                    similarity_measure=similarity_measure,
-                    nearest_neighbor_correlation=nearest_corr,
-                    furthest_neighbor_correlation=furthest_corr,
-                    score_=score_))
+                    raise InvalidConfigurationError(f"{optim_algo} " f"not implemented")
+                all_scores.append(
+                    trial_(
+                        fingerprint_type=fingerprint_type,
+                        similarity_measure=similarity_measure,
+                        nearest_neighbor_correlation=nearest_corr,
+                        furthest_neighbor_correlation=furthest_corr,
+                        score_=score_,
+                    )
+                )
         all_scores.sort(key=lambda x: x[-1], reverse=True)
         if self.log_fpath is not None:
-            print('Writing to ', self.log_fpath)
+            print("Writing to ", self.log_fpath)
             log_data = [trial._asdict() for trial in all_scores]
             with open(self.log_fpath, "w") as fp:
                 json.dump(log_data, fp)
@@ -210,46 +231,58 @@ class MeasureSearch(Task):
             all_measures = []
             for trial in top_performers:
                 all_nearest_neighbor_correlations.append(
-                    trial.nearest_neighbor_correlation)
+                    trial.nearest_neighbor_correlation
+                )
                 all_furthest_neighbor_correlations.append(
-                    trial.furthest_neighbor_correlation)
+                    trial.furthest_neighbor_correlation
+                )
                 top_scores.append(trial.score_)
-                all_measures.append(Descriptor.shorten_label(
-                    trial.fingerprint_type)
-                    + '\n'
-                    + trial.similarity_measure)
-            bar_heights = np.array([top_scores,
-                                    all_nearest_neighbor_correlations,
-                                    all_furthest_neighbor_correlations])
-            colors = self.plot_settings.pop('colors')
-            plot_multiple_barchart(x=[_ for _ in range(len(top_performers))],
-                                   heights=bar_heights,
-                                   legend_labels=['Overall scores',
-                                                  'Nearest neighbor property '
-                                                  'correlation',
-                                                  'Furthest neighbor property '
-                                                  'correlations'],
-                                   colors=colors,
-                                   xtick_labels=all_measures,
-                                   ylabel='Value',
-                                   xlabel='Measure',
-                                   **self.plot_settings)
+                all_measures.append(
+                    Descriptor.shorten_label(trial.fingerprint_type)
+                    + "\n"
+                    + trial.similarity_measure
+                )
+            bar_heights = np.array(
+                [
+                    top_scores,
+                    all_nearest_neighbor_correlations,
+                    all_furthest_neighbor_correlations,
+                ]
+            )
+            colors = self.plot_settings.pop("colors")
+            plot_multiple_barchart(
+                x=[_ for _ in range(len(top_performers))],
+                heights=bar_heights,
+                legend_labels=[
+                    "Overall scores",
+                    "Nearest neighbor property " "correlation",
+                    "Furthest neighbor property " "correlations",
+                ],
+                colors=colors,
+                xtick_labels=all_measures,
+                ylabel="Value",
+                xlabel="Measure",
+                **self.plot_settings,
+            )
 
         return all_scores[0]
 
     def __str__(self):
-        return "Task: determine appropriate fingerprint type and " \
-               "similarity measure for property of interest"
+        return (
+            "Task: determine appropriate fingerprint type and "
+            "similarity measure for property of interest"
+        )
 
-    def get_best_measure(self,
-                         molecule_set_configs,
-                         fingerprint_type=None,
-                         similarity_measure=None,
-                         subsample_subset_size=0.01,
-                         optim_algo='max_min',
-                         only_metric=False,
-                         show_top=0,
-                         ):
+    def get_best_measure(
+        self,
+        molecule_set_configs,
+        fingerprint_type=None,
+        similarity_measure=None,
+        subsample_subset_size=0.01,
+        optim_algo="max_min",
+        only_metric=False,
+        show_top=0,
+    ):
         """Get the best measure for quantity of interest.
 
         Args:
